==> jc-1.4.0.tar.gz: polyglot/frontend/EmptyPass.h <==
// public class polyglot.frontend.EmptyPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class b5794ee2faecc7b2 polyglot_frontend_EmptyPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_EmptyPass_H_
#define _JC_polyglot_frontend_EmptyPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_EmptyPass$sub_refs	_jc_polyglot_frontend_EmptyPass$sub_refs;
typedef struct _jc_polyglot_frontend_EmptyPass$sub_nonrefs	_jc_polyglot_frontend_EmptyPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_EmptyPass$refs	_jc_polyglot_frontend_EmptyPass$refs;
typedef struct _jc_polyglot_frontend_EmptyPass$nonrefs	_jc_polyglot_frontend_EmptyPass$nonrefs;
typedef struct _jc_polyglot_frontend_EmptyPass$object	_jc_polyglot_frontend_EmptyPass$object;

typedef const struct _jc_polyglot_frontend_EmptyPass$vmethods	_jc_polyglot_frontend_EmptyPass$vmethods;
typedef const struct _jc_polyglot_frontend_EmptyPass$vtable	_jc_polyglot_frontend_EmptyPass$vtable;
typedef const struct _jc_polyglot_frontend_EmptyPass$vtype	_jc_polyglot_frontend_EmptyPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_EmptyPass$method$_init$2bdf2b720377758d(_jc_env *, struct _jc_polyglot_frontend_EmptyPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_EmptyPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_EmptyPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_EmptyPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_EmptyPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_EmptyPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_EmptyPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_EmptyPass$vmethods	polyglot_frontend_EmptyPass;
};

// Vtype
struct _jc_polyglot_frontend_EmptyPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_EmptyPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_EmptyPass$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_EmptyPass$refs {
    _jc_polyglot_frontend_EmptyPass$sub_refs	polyglot_frontend_EmptyPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_EmptyPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_EmptyPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_EmptyPass$sub_nonrefs	polyglot_frontend_EmptyPass;
};

// Object instance structure
struct _jc_polyglot_frontend_EmptyPass$object {
	_jc_polyglot_frontend_EmptyPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_EmptyPass$vtype	*vtype;
	_jc_polyglot_frontend_EmptyPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_EmptyPass$vtype _jc_polyglot_frontend_EmptyPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_EmptyPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_EmptyPass$class_object;

#endif	/* _JC_polyglot_frontend_EmptyPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/EmptyPass.h <==
// public class polyglot.frontend.EmptyPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class b5794ee2faecc7b2 polyglot_frontend_EmptyPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_EmptyPass_H_
#define _JC_polyglot_frontend_EmptyPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_EmptyPass$sub_refs	_jc_polyglot_frontend_EmptyPass$sub_refs;
typedef struct _jc_polyglot_frontend_EmptyPass$sub_nonrefs	_jc_polyglot_frontend_EmptyPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_EmptyPass$refs	_jc_polyglot_frontend_EmptyPass$refs;
typedef struct _jc_polyglot_frontend_EmptyPass$nonrefs	_jc_polyglot_frontend_EmptyPass$nonrefs;
typedef struct _jc_polyglot_frontend_EmptyPass$object	_jc_polyglot_frontend_EmptyPass$object;

typedef const struct _jc_polyglot_frontend_EmptyPass$vmethods	_jc_polyglot_frontend_EmptyPass$vmethods;
typedef const struct _jc_polyglot_frontend_EmptyPass$vtable	_jc_polyglot_frontend_EmptyPass$vtable;
typedef const struct _jc_polyglot_frontend_EmptyPass$vtype	_jc_polyglot_frontend_EmptyPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_EmptyPass$method$_init$2bdf2b720377758d(_jc_env *, struct _jc_polyglot_frontend_EmptyPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_EmptyPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_EmptyPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_EmptyPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_EmptyPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_EmptyPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_EmptyPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_EmptyPass$vmethods	polyglot_frontend_EmptyPass;
};

// Vtype
struct _jc_polyglot_frontend_EmptyPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_EmptyPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_EmptyPass$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_EmptyPass$refs {
    _jc_polyglot_frontend_EmptyPass$sub_refs	polyglot_frontend_EmptyPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_EmptyPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_EmptyPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_EmptyPass$sub_nonrefs	polyglot_frontend_EmptyPass;
};

// Object instance structure
struct _jc_polyglot_frontend_EmptyPass$object {
	_jc_polyglot_frontend_EmptyPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_EmptyPass$vtype	*vtype;
	_jc_polyglot_frontend_EmptyPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_EmptyPass$vtype _jc_polyglot_frontend_EmptyPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_EmptyPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_EmptyPass$class_object;

#endif	/* _JC_polyglot_frontend_EmptyPass_H_ */
